@@ -5,6 +5,8 @@ from uuid import UUID
 
 from tabulate import tabulate
 
+from preseem_protobuf.model.element_pb2 import ElementStatus
+
 # STM-6039 Only allow the sync to run once at a time, to prevent duplicate
 # entities from being created.
 sync_lock = asyncio.Lock()
@@ -124,7 +126,8 @@ async def sync_preseem_model(preseem_model,
                         company_uuid=company_uuid,
                         site_uuid=site_uuid,
                         name=name,
-                        management_ip=ip)
+                        management_ip=ip,
+                        status=ElementStatus.ELEMENT_STATUS_UNKNOWN)
                     logging.info('sync_preseem_model: created element "%s"',
                                  UUID(bytes=elem.uuid))
                     linked_elems.add(elem.uuid)
